@@ -190,7 +190,7 @@ class ViewContainer(Stack):
             set_sensitive(len(items) > 0)
         if len(items) > 0:
             self.header_bar._selection_menu_label.set_text(
-                ngettext(_("Selected %d item"), _("Selected %d items"), len(items)) % len(items))
+                ngettext("Selected %d item", "Selected %d items", len(items)) % len(items))
         else:
             self.header_bar._selection_menu_label.set_text(_("Click on items to select them"))
 
@@ -237,6 +237,7 @@ class ViewContainer(Stack):
 
     def _on_discovered(self, info, error, _iter):
         if error:
+            print("Info %s: error: %s" % (info, error))
             self._model.set(_iter, [8, 10], [self.errorIconName, True])
 
     def _add_item(self, source, param, item, remaining):
@@ -420,6 +421,8 @@ class Songs(ViewContainer):
 
         child_iter = self.filter.convert_iter_to_child_iter(currentIter)
         self._model.set_value(child_iter, 10, True)
+        path = self._model.get_path(child_iter)
+        self.view.get_generic_view().scroll_to_path(path)
         if self._model.get_value(child_iter, 8) != self.errorIconName:
             self.iter_to_clean = child_iter.copy()
         return False
@@ -975,7 +978,7 @@ class Playlist(ViewContainer):
 
     def _update_songs_count(self):
         self.songs_count_label.set_text(
-            ngettext(_("%d Song"), _("%d Songs"), self.songs_count)
+            ngettext("%d Song", "%d Songs", self.songs_count)
             % self.songs_count)
 
     def _on_selection_mode_changed(self, widget, data=None):
