@@ -208,11 +208,12 @@ class Window(Gtk.ApplicationWindow):
             count = count + 1
         if count > 0:
             self.toolbar._selection_menu_label.set_text(
-                ngettext(_("Selected %d item"), _("Selected %d items"), count) % count)
+                ngettext("Selected %d item", "Selected %d items", count) % count)
             self.selection_toolbar._add_to_playlist_button.set_sensitive(True)
             self.selection_toolbar._remove_from_playlist_button.set_sensitive(True)
         elif count == 0:
             self.toolbar._selection_menu_label.set_text(_("Click on items to select them"))
+        self._stack.get_visible_child().queue_draw()
 
     def _on_select_none(self, action, param):
         if self.toolbar._state != ToolbarState.SINGLE:
@@ -226,21 +227,33 @@ class Window(Gtk.ApplicationWindow):
             model.set(_iter, [6], [False])
             _iter = model.iter_next(_iter)
         self.toolbar._selection_menu_label.set_text(_("Click on items to select them"))
+        self._stack.get_visible_child().queue_draw()
 
     def _on_key_press(self, widget, event):
         modifiers = Gtk.accelerator_get_default_mod_mask()
+        event_and_modifiers = (event.state & modifiers)
 
-        if (event.keyval == Gdk.KEY_f and
-                (event.state & modifiers) == Gdk.ModifierType.CONTROL_MASK):
-            self.toolbar.searchbar.toggle_bar()
-        elif (event.keyval == Gdk.KEY_Escape and (event.state & modifiers) == 0):
-            self.toolbar.searchbar.show_bar(False)
-            if self.toolbar._selectionMode:
-                self.toolbar.set_selection_mode(False)
-        elif (event.state & modifiers) == 0 and \
-                event.keyval in range(33, 126) and \
-                not self.toolbar.searchbar.get_reveal_child():
-            self.toolbar.searchbar.show_bar(True)
+        if event_and_modifiers != 0:
+            # Open search bar on Ctrl + F
+            if (event.keyval == Gdk.KEY_f and
+                    event_and_modifiers == Gdk.ModifierType.CONTROL_MASK):
+                self.toolbar.searchbar.toggle_bar()
+        else:
+            # Close search bar after Esc is pressed
+            if event.keyval == Gdk.KEY_Escape:
+                self.toolbar.searchbar.show_bar(False)
+                # Also disable selection
+                if self.toolbar._selectionMode:
+                    self.toolbar.set_selection_mode(False)
+
+        # Open search bar when typing printable chars if it not opened
+        # Make sure we skip unprintable chars and don't grab space press
+        # (this is used for play/pause)
+        if not self.toolbar.searchbar.get_reveal_child() and not event.keyval == Gdk.KEY_space:
+            if (event_and_modifiers == Gdk.ModifierType.SHIFT_MASK or
+                    event_and_modifiers == 0) and \
+                    GLib.unichar_isprint(chr(Gdk.keyval_to_unicode(event.keyval))):
+                self.toolbar.searchbar.show_bar(True)
 
     def _notify_mode_disconnect(self, data=None):
         self._stack.disconnect(self._on_notify_model_id)
